#
# spec file for package guestfs-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needsbinariesforbuild


%global patches_touch_autotools 1

# The source directory.
%global source_directory 1.52-stable

#
%define guestfs_docdir %{_defaultdocdir}/%{name}

# Filter perl provides.
%{?perl_default_filter}

Summary:        Tools to access and modify virtual machine disk images
Name:           guestfs-tools
Version:        1.52.0
Release:        2.3
License:        GPL-2.0-or-later

# Build only for architectures that have a kernel
ExclusiveArch:  x86_64 ppc64le s390x aarch64 riscv64

# Source and patches.
URL:            http://libguestfs.org/
Source0:        http://download.libguestfs.org/guestfs-tools/%{source_directory}/%{name}-%{version}.tar.gz
Source1:        http://download.libguestfs.org/guestfs-tools/%{source_directory}/%{name}-%{version}.tar.gz.sig

%if 0%{patches_touch_autotools}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
BuildRequires:  libtool
%endif

# Basic build requirements.
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libguestfs-devel >= 1.45.3-1
BuildRequires:  libguestfs-xfs
BuildRequires:  libjansson-devel
BuildRequires:  libosinfo-devel
BuildRequires:  libvirt-devel
BuildRequires:  libxcrypt-devel
BuildRequires:  libxml2-devel
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-gettext-devel
BuildRequires:  ocaml-libguestfs-devel
BuildRequires:  ocaml-ounit-devel
BuildRequires:  pcre2-devel
BuildRequires:  perl
BuildRequires:  po4a
BuildRequires:  qemu-tools
BuildRequires:  unzip
BuildRequires:  xorriso
BuildRequires:  xz-devel
BuildRequires:  zip
BuildRequires:  ocaml(ocaml_base_version) >= 4.07
BuildRequires:  perl(Expect)
BuildRequires:  perl(Locale::TextDomain)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Pod::Man)
BuildRequires:  perl(Pod::Simple)
BuildRequires:  perl(Sys::Guestfs)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Win::Hivex)
BuildRequires:  perl(Win::Hivex::Regedit)
BuildRequires:  pkgconfig(bash-completion)

# For virt-builder:
Requires:       curl
Requires:       gpg2
###Requires:      /usr/bin/qemu-img
Requires:       xz

# Obsolete guestfs-tools from the libguestfs package
Provides:       %{name} < %{version}
Obsoletes:      %{name} < %{version}

# For virt-builder-repository:
Suggests:       osinfo-db

# For virt-inspector, since Fedora and RHEL >= 7 use XFS:
Recommends:     libguestfs-xfs

# For virt-edit and virt-customize:
Suggests:       perl

%description
guestfs-tools is a set of tools that can be used to make batch
configuration changes to guests, get disk used/free statistics
(virt-df), perform backups and guest clones, change
registry/UUID/hostname info, build guests from scratch (virt-builder)
and much more.

Virt-alignment-scan scans virtual machines looking for partition
alignment problems.

Virt-builder is a command line tool for rapidly making disk images
of popular free operating systems.

Virt-cat is a command line tool to display the contents of a file in a
virtual machine.

Virt-customize is a command line tool for customizing virtual machine
disk images.

Virt-df is a command line tool to display free space on virtual
machine filesystems.  Unlike other tools, it doesn’t just display the
amount of space allocated to a virtual machine, but can look inside
the virtual machine to see how much space is really being used.  It is
like the df(1) command, but for virtual machines, except that it also
works for Windows virtual machines.

Virt-diff shows the differences between virtual machines.

Virt-edit is a command line tool to edit the contents of a file in a
virtual machine.

Virt-filesystems is a command line tool to display the filesystems,
partitions, block devices, LVs, VGs and PVs found in a disk image
or virtual machine.  It replaces the deprecated programs
virt-list-filesystems and virt-list-partitions with a much more
capable tool.

Virt-format is a command line tool to erase and make blank disks.

Virt-get-kernel extracts a kernel/initrd from a disk image.

Virt-inspector examines a virtual machine and tries to determine the
version of the OS, the kernel version, what drivers are installed,
whether the virtual machine is fully virtualized (FV) or
para-virtualized (PV), what applications are installed and more.

Virt-log is a command line tool to display the log files from a
virtual machine.

Virt-ls is a command line tool to list out files in a virtual machine.

Virt-make-fs is a command line tool to build a filesystem out of
a collection of files or a tarball.

Virt-resize can resize existing virtual machine disk images.

Virt-sparsify makes virtual machine disk images sparse (thin-provisioned).

Virt-sysprep lets you reset or unconfigure virtual machines in
preparation for cloning them.

Virt-tail follows (tails) a log file within a guest, like 'tail -f'.

%package -n virt-win-reg
Summary:        Access and modify the Windows Registry of a Windows VM
BuildArch:      noarch

%description -n virt-win-reg
Virt-win-reg lets you look at and modify the Windows Registry of
Windows virtual machines.

%package bash-completion
Summary:        Bash tab-completion scripts for %{name}
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       bash-completion >= 2.0

%description bash-completion
Install this package if you want intelligent bash tab-completion
for the virt-* tools.

%package man-pages-ja
Summary:        Japanese (ja) man pages for %{name}
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description man-pages-ja
%{name}-man-pages-ja contains Japanese (ja) man pages
for %{name}.

%package man-pages-uk
Summary:        Ukrainian (uk) man pages for %{name}
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description man-pages-uk
%{name}-man-pages-uk contains Ukrainian (uk) man pages
for %{name}.

%prep
%autosetup -p1

%if 0%{patches_touch_autotools}
autoreconf -i
%endif

%build
%{configure} \
        --docdir=%{guestfs_docdir}

# Building index-parse.c by hand works around a race condition in the
# autotools cruft, where two or more copies of yacc race with each
# other, resulting in a corrupted file.
make -j1 -C builder index-parse.c

make V=1 %{?_smp_mflags}

%check

%install
%makeinstall \
        DESTDIR=%{buildroot} \
        INSTALLDIRS=vendor

# Delete libtool files.
find %{buildroot} -name '*.la' -delete

# Move installed documentation back to the source directory so
# we can install it using a %%doc rule.
mv %{buildroot}%{_docdir}/%{name} installed-docs
gzip -n --best installed-docs/*.xml

# Remove virt-dib if it was built.
rm -f $RPM_BUILD_ROOT%{_bindir}/virt-dib
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/virt-dib.1*

# Find locale files.
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc README
%doc installed-docs/*
%dir %{_sysconfdir}/virt-builder
%dir %{_sysconfdir}/virt-builder/repos.d
%config(noreplace) %{_sysconfdir}/virt-builder/repos.d/*
%{_bindir}/virt-alignment-scan
%{_bindir}/virt-builder
%{_bindir}/virt-builder-repository
%{_bindir}/virt-cat
%{_bindir}/virt-customize
%{_bindir}/virt-df
%{_bindir}/virt-diff
%{_bindir}/virt-drivers
%{_bindir}/virt-edit
%{_bindir}/virt-filesystems
%{_bindir}/virt-format
%{_bindir}/virt-get-kernel
%{_bindir}/virt-index-validate
%{_bindir}/virt-inspector
%{_bindir}/virt-log
%{_bindir}/virt-ls
%{_bindir}/virt-make-fs
%{_bindir}/virt-resize
%{_bindir}/virt-sparsify
%{_bindir}/virt-sysprep
%{_bindir}/virt-tail
%{_mandir}/man1/guestfs-tools-release-notes-1.*.1.gz
%{_mandir}/man1/virt-alignment-scan.1*
%{_mandir}/man1/virt-builder-repository.1*
%{_mandir}/man1/virt-builder.1*
%{_mandir}/man1/virt-cat.1*
%{_mandir}/man1/virt-customize.1*
%{_mandir}/man1/virt-df.1*
%{_mandir}/man1/virt-diff.1*
%{_mandir}/man1/virt-drivers.1*
%{_mandir}/man1/virt-edit.1*
%{_mandir}/man1/virt-filesystems.1*
%{_mandir}/man1/virt-format.1*
%{_mandir}/man1/virt-get-kernel.1*
%{_mandir}/man1/virt-index-validate.1*
%{_mandir}/man1/virt-inspector.1*
%{_mandir}/man1/virt-log.1*
%{_mandir}/man1/virt-ls.1*
%{_mandir}/man1/virt-make-fs.1*
%{_mandir}/man1/virt-resize.1*
%{_mandir}/man1/virt-sparsify.1*
%{_mandir}/man1/virt-sysprep.1*
%{_mandir}/man1/virt-tail.1*

%files -n virt-win-reg
%license COPYING
%doc README
%{_bindir}/virt-win-reg
%{_mandir}/man1/virt-win-reg.1*

%files bash-completion
%license COPYING
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/virt-*

%files man-pages-ja
%lang(ja) %{_mandir}/ja/man1/*.1*
%if 0%{?suse_version} <= 1500
%dir %{_mandir}/ja
%dir %{_mandir}/ja/man1
%endif

%files man-pages-uk
%lang(uk) %{_mandir}/uk/man1/*.1*
%if 0%{?suse_version} <= 1500
%dir %{_mandir}/uk
%dir %{_mandir}/uk/man1
%endif

%changelog
* Thu Jan  4 2024 carnold@suse.com
- Update to version 1.52.0 (jsc#PED-6305)
  * mltools/libosinfo-c.c: Fix off-by-one error
  * Documentation fixes
  * Fix bugs-in-changelog.sh: Use grep -E instead of egrep
* Mon Dec 11 2023 carnold@suse.com
- Update to version 1.51.6
  * Include <libxml/parser.h> for xmlReadMemory
  * Test new --key all:SELECTOR option
* Thu Nov 30 2023 olaf@aepfle.de
- Remove obsolete requirement for ocaml-gettext-stub-devel
- Require OCaml 4.07+
* Tue Nov 28 2023 carnold@suse.com
- Update to version 1.51.5
  * No upstream changelog found in sources or webpage
  * customize: Change --chown to use UID:GID:FILENAME
  * Implement virt-customize --tar-in
  * Dropped the virt-dib tool
  * Various bug fixes and language translations
* Mon May  1 2023 carnold@suse.com
- Update to version 1.50.1 bug fix release
  * No upstream changelog found in sources or webpage
* Fri Mar 17 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Use gzip -n for bit-reproducible packages
* Thu Feb  9 2023 carnold@suse.com
- Update to verion 1.50.0
  * Drivers: Require guestfs_inspect_get_build_id API
  * Drivers: Add support for scanning drivers in Windows guests
  * New 'virt-drivers' tool
    This tool can be pointed at a disk image which lacks metadata and in
    some circumstances can determine useful information about it, such as
    what bootloader it contains and what device emulation it needs to
    boot.
  * Customize: Implement --inject-qemu-ga and --inject-virtio-win operations
  * Customize: Run zypper dist-upgrade for --update operation
  * Customize: rebase to the common/mlcustomize/Guest_packages interface
  * Adopt inversion of SELinux relabeling in virt-customize
  * Update common submodule. In particular, pick up the new Inject_virtio_win module:
  * Inspector: Update coreos test for new <build_id> field
  * Inspector: Display the new build ID field
  * Sysprep: advise against cloning VMs with internal full disk encryption
  * Sysprep: make an effort to cope with LUKS-on-LVM
  * Fixes related to "--key ID:clevis"
    sysprep: set networking for "--key ID:clevis"
    customize: add reminder about "--key ID:clevis"
    get-kernel, sparsify: set networking for "--key ID:clevis"
    cat, log, ls, tail, diff, edit, insp.: set networking for "--key ID:clevis"
  * Builder: templates: Account for UEFI when regenerating grub
  * Ocaml-dep.sh.in: Remove reference to bundled/ocaml-augeas
- Drop CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
* Wed Jan 25 2023 carnold@suse.com
- Update to version 1.48.3 bug fix release
  * jsc#PED-2113
  * No upstream changelog found in sources or webpage
* Tue Dec 27 2022 Andreas Schwab <schwab@suse.de>
- Enable build on riscv64
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2104 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Wed Jun 29 2022 carnold@suse.com
- bsc#1201064 - Libguestfs: Buffer overflow in get_keys leads
  to DOS - CVE-2022-2211
  CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
* Thu Jun  2 2022 carnold@suse.com
- Update to version 1.48.2
  * This is a bug fix release
* Mon May 16 2022 carnold@suse.com
- Update to version 1.48.1
  * This is a bug fix release
* Thu Mar 17 2022 carnold@suse.com
- Update to version 1.48.0
  * virt-builder
    New templates: "alma-8.5", "centosstream-8", "debian-11",
    "fedora-34", "fedora-34" (armv7l), "fedora-35" "fedora-35"
    (aarch64) (Lars Kaiser, Stef Walter).
    New fedora-34 (armv7l) template is built to use UEFI.
  * virt-customize
    The yescrypt password hashing method is now supported (Björn
    Esser).
  * virt-inspector
    Recognise "kalilinux", "kylin" and "msdos" operating systems /
    Linux distros (Laszlo Ersek).
    Inspection of LUKS encrypted filesystems placed directly on
    logical volumes is now supported, but you will need
    libguestfs ≥ 1.48 (Laszlo Ersek).
  * virt-sysprep
    Add a new default operation called "net-nmconn" which removes
    NetworkManager connection profiles (Laszlo Ersek).
  * virt-win-reg
    "virt-win-reg --version" now prints both the version of guestfs
    tools and the libguestfs library that it is linked with.
  * Various bug fixes
- Drop patches contained in new tarball
  63c9cd93-m4-guestfs-ocaml.m4-Fix-deprecated-warning-format.patch
  a4930f5f-customize-Suppress-OCaml-warning.patch
* Thu Dec 30 2021 Vasily Ulyanov <vasily.ulyanov@suse.com>
- Fix Requires: gnupg2 -> gpg2
* Fri Dec 17 2021 carnold@suse.com
- Initial creation of the guestfs-tools package split out from the
  libguestfs package.
  * This release moves many of the virt tools like virt-builder,
    virt-cat, virt-customize, virt-df, etc. from libguestfs to the
    guestfs-tools package. This makes libguestfs a bit easier to
    build and manage.
- These patches fix ocaml build errors.
  63c9cd93-m4-guestfs-ocaml.m4-Fix-deprecated-warning-format.patch
  a4930f5f-customize-Suppress-OCaml-warning.patch
